@@ -8,8 +8,8 @@ class Newton:
         self.api_base = "https://api.objectways.com/v1"
 
         if mode == "test":
-            self.api.base = "https://devapi.objectways.com/v1"
-            
+            self.api_base = "https://devapi.objectways.com/v1"
+
         self.__headers = {"Content-Type": "application/json", "api_key": api_key}
 
     @staticmethod
